#[non_exhaustive]pub struct LocationMessageEventContent {
pub body: String,
pub geo_uri: String,
pub info: Option<Box<LocationInfo>>,
pub message: Option<TextContentBlock>,
pub location: Option<LocationContent>,
pub asset: Option<AssetContent>,
pub ts: Option<MilliSecondsSinceUnixEpoch>,
}Expand description
The payload for a location message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.body: StringA description of the location e.g. “Big Ben, London, UK”, or some kind of content description for accessibility, e.g. “location attachment”.
geo_uri: StringA geo URI representing the location.
info: Option<Box<LocationInfo>>Info about the location being represented.
message: Option<TextContentBlock>Extensible-event text representation of the message.
If present, this should be preferred over the body field.
location: Option<LocationContent>Extensible-event location info of the message.
If present, this should be preferred over the geo_uri field.
asset: Option<AssetContent>Extensible-event asset this message refers to.
ts: Option<MilliSecondsSinceUnixEpoch>Extensible-event timestamp this message refers to.
Implementations
Sourceimpl LocationMessageEventContent
impl LocationMessageEventContent
Sourcepub fn new(body: String, geo_uri: String) -> Self
pub fn new(body: String, geo_uri: String) -> Self
Creates a new LocationMessageEventContent with the given body and geo URI.
Sourcepub fn with_asset_type(self, asset: AssetType) -> Self
pub fn with_asset_type(self, asset: AssetType) -> Self
Set the asset type of this LocationMessageEventContent.
Sourcepub fn with_ts(self, ts: MilliSecondsSinceUnixEpoch) -> Self
pub fn with_ts(self, ts: MilliSecondsSinceUnixEpoch) -> Self
Set the timestamp of this LocationMessageEventContent.
Sourcepub fn plain_text_representation(&self) -> &str
pub fn plain_text_representation(&self) -> &str
Get the plain text representation of this LocationMessageEventContent.
Sourcepub fn asset_type(&self) -> AssetType
pub fn asset_type(&self) -> AssetType
Get the asset type of this LocationMessageEventContent.